@@ -11,7 +11,7 @@ from enum import Enum
 List  = typing.List
 Tuple = typing.Tuple
 pypi_base_url = "http://zifuture.com:1556/fs/pypi"
-version = "1.1.26"
+version = "1.1.27"
 nvbin_version = "v6.0"
 
 lean_metas = [
@@ -507,6 +507,31 @@ def set_exec_permission(directory):
             print(f"Set execute permission: {full_path}")
             os.chmod(full_path, stat.S_IRWXU)
 
+def get_cpp_pkg(name):
+    from . import downloader
+    url = f"{pypi_base_url}/cpp-packages/{name}.zip"
+
+    file = os.path.join(downloader.CACHE_ROOT, "cpp-packages", f"{name}.zip")
+    ok, md5 = downloader.download_and_verify_md5_saveto_file(url, file)
+    if not ok:
+        print(f"Failed to fetch cpp package {name}")
+        return False
+
+    package_root = os.path.join(cpp_packages_root, name)
+    package_lib_root = os.path.join(package_root, "lib")
+    if os.path.isdir(package_root):
+        print(f"Remove old package files {package_root}")
+        import shutil
+        shutil.rmtree(package_root)
+
+    print(f"Extract package {name} to {package_root}")
+    downloader.extract_zip_to(file, cpp_packages_root, False)
+    if os.path.isdir(package_lib_root):
+        print(f"Create symlink {package_lib_root}")
+        create_symlink_directory(package_lib_root, True)
+    print(f"{name} Done")
+    return True
+
 def __load_symbols(pyc_meta, load_lean_library=True):
 
     global module_variables, loaded_module, inited
@@ -602,7 +627,7 @@ def __load_symbols(pyc_meta, load_lean_library=True):
                     set_exec_permission(os.path.join(d, itemd))
 
         create_symlink_directory(nvlib64_root, True)
-
+        get_cpp_pkg("opencv4.2")
 
     if os.path.exists(pyc_version_path):
         current_pyc_version = open(pyc_version_path, "r").read()
